Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1159)

Unified Diff: ios/web_view/shell/shell_view_controller.m

Issue 2703413004: Rename CRIWV class to CWV. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web_view/shell/shell_app_delegate.m ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web_view/shell/shell_view_controller.m
diff --git a/ios/web_view/shell/shell_view_controller.m b/ios/web_view/shell/shell_view_controller.m
index f1b5f89f6a0090b034b685e01c93b2ac095bf892..c95398b126c4221cde995e13b9bd8a5223cfd8c9 100644
--- a/ios/web_view/shell/shell_view_controller.m
+++ b/ios/web_view/shell/shell_view_controller.m
@@ -4,7 +4,7 @@
#import "ios/web_view/shell/shell_view_controller.h"
-#import "ios/web_view/public/criwv.h"
+#import "ios/web_view/public/cwv.h"
#import "ios/web_view/public/cwv_web_view.h"
#import "ios/web_view/shell/translate_controller.h"
@@ -19,7 +19,7 @@
@property(nonatomic, strong) UITextField* field;
// Toolbar containing navigation buttons and |field|.
@property(nonatomic, strong) UIToolbar* toolbar;
// CRIWV view which renders the web page.
@property(nonatomic, strong) CWVWebView* webView;
// Handles the translation of the content displayed in |webView|.
@property(nonatomic, strong) TranslateController* translateController;
@@ -120,7 +120,7 @@
[_toolbar addSubview:stop];
[_toolbar addSubview:_field];
- self.webView = [CRIWV webViewWithFrame:[_containerView bounds]];
+ self.webView = [CWV webViewWithFrame:[_containerView bounds]];
[_webView setDelegate:self];
[_webView setAutoresizingMask:UIViewAutoresizingFlexibleWidth |
UIViewAutoresizingFlexibleHeight];
@@ -19,7 +19,7 @@
// Toolbar containing navigation buttons and |field|.
-// CRIWV view which renders the web page.
+// CWV view which renders the web page.
// Handles the translation of the content displayed in |webView|.
« no previous file with comments | « ios/web_view/shell/shell_app_delegate.m ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698